:github_url:

.. _wineenv:

.. index::
	single: env python
	single: env pip
	single: env pytest
	single: env init
	triple: wine; python; environment
	module: wenv.Env

Environment
===========

Wine Python environments can be created, managed and destroyed using this API.  

.. autoclass:: wenv.Env
    :members:
